"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchAndStoreRules = fetchAndStoreRules;
const axios_1 = __importDefault(require("axios"));
const jsdom_1 = require("jsdom");
const node_fs_1 = __importDefault(require("node:fs"));
const constants_1 = require("./constants");
async function fetchAndStoreRules() {
    var _a;
    const response = await axios_1.default.get('https://typescript-eslint.io/rules/#extension-rules');
    const html = response.data;
    const dom = new jsdom_1.JSDOM(html);
    const rulesTable = dom.window.document.querySelector('h2#rules ~ table tbody');
    if (!rulesTable) {
        throw new Error(`could not fetch rules`);
    }
    const allRules = [...rulesTable.children];
    const rulesRequiringTypeInfo = [];
    for (const tr of allRules) {
        const ruleRequiresTypeInfo = tr.querySelector('td[title="requires type information"]');
        if (ruleRequiresTypeInfo) {
            const ruleAnchor = tr.querySelector('td:first-child a');
            if (!ruleAnchor) {
                throw new Error(`found a rule but could not extract rule anchor`);
            }
            const nameOfRule = (_a = ruleAnchor.textContent) === null || _a === void 0 ? void 0 : _a.trim();
            if (!nameOfRule) {
                throw new Error(`found a rule but could not extract name of the rule`);
            }
            rulesRequiringTypeInfo.push(nameOfRule);
        }
    }
    await node_fs_1.default.promises.writeFile(constants_1.constants.RULES_PATH, JSON.stringify(rulesRequiringTypeInfo), {
        encoding: 'utf8',
    });
}
//# sourceMappingURL=fetch-and-store-rules.js.map